.. gefera documentation master file, created by
   sphinx-quickstart on Thu May 26 16:48:54 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to gefera's documentation!
==================================

.. toctree::
   :maxdepth: 2
   :caption: User Guide:

   user/install
   user/citation

.. toctree::
   :maxdepth: 1
   :caption: API:

   autoapi/gefera/orbits/index
   autoapi/gefera/systems/index
   autoapi/gefera/animate/index

.. toctree::
   :maxdepth: 1
   :caption: Tutorials:

   tutorials/kep51_demo.ipynb 
   tutorials/moon_demo.ipynb

.. only:: builder_html

   :download:`Kepler-51 data<tutorials/k51.txt>`

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
